bayespy.inference.vmp.nodes.stochastic.Distribution.compute_mask_to_parent
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Distribution.compute_mask_to_parent